@@ -18,17 +18,27 @@ module Dotenv
           \}?           # closing brace
         /xi
 
-        def call(value, env)
+        def call(value, env, is_load)
+          combined_env = if is_load
+                           env.merge(ENV)
+                         else
+                           ENV.to_h.merge(env)
+                         end
           value.gsub(VARIABLE) do |variable|
             match = $LAST_MATCH_INFO
+            substitute(match, variable, combined_env)
+          end
+        end
 
-            if match[1] == '\\'
-              variable[1..-1]
-            elsif match[3]
-              env.fetch(match[3]) { ENV[match[3]] }
-            else
-              variable
-            end
+        private
+
+        def substitute(match, variable, env)
+          if match[1] == '\\'
+            variable[1..-1]
+          elsif match[3]
+            env.fetch(match[3], "")
+          else
+            variable
           end
         end
       end
